@@ -78,7 +78,7 @@ def test_cmd_codegen(fx_get_sub_parser, fx_cmd_line_args_codegen_package):
     $ resilient-sdk codegen -p <name_of_package> -m 'fn_custom_md' --rule 'Rule One' 'Rule Two' -i 'custom incident type'
     $ resilient-sdk codegen -p <path_current_package> --reload --workflow 'new_wf_to_add'"""
     assert cmd_codegen.CMD_DESCRIPTION == "Generate boilerplate code to start developing an app"
-    assert cmd_codegen.CMD_ADD_PARSERS == ["res_obj_parser", "io_parser"]
+    assert cmd_codegen.CMD_ADD_PARSERS == ["app_config_parser", "res_obj_parser", "io_parser"]
 
     args = cmd_codegen.parser.parse_known_args()[0]
     assert args.package == "fn_main_mock_integration"
